import { InMemoryCache, ApolloClient, useQuery, gql, ApolloProvider } from '@apollo/client';
export { gql, useMutation, useQuery } from '@apollo/client';
import React, { useState, useEffect, useContext, createContext } from 'react';
import styled from 'styled-components';
import { Stack, IconButton, SettingsIcon, PagesIcon, NetIcon, BotIcon, PerformDropdown, PerformDropdownButton, Image, Text, PerformDropdownList, PerformDropdownItem, Heading, Menu, MenuButton, Button, ArrowUpIcon, ArrowDownIcon, MenuList, MenuGroup, MenuItem, CloseIcon, Main, Navbar, Flex, Footer } from 'bonde-components';
import { CrossStorageClient } from 'cross-storage';
import axios from 'axios';
import logger$1 from 'pino';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _taggedTemplateLiteralLoose(strings, raw) {
  if (!raw) {
    raw = strings.slice(0);
  }

  strings.raw = raw;
  return strings;
}

var SessionStorage = /*#__PURE__*/function () {
  function SessionStorage(uri) {
    this.session = {};
    this.authenticated = false; // Init session client on cross-storage

    this.storage = new CrossStorageClient(uri, {
      timeout: 10000
    });
  }

  var _proto = SessionStorage.prototype;

  _proto.login = function login(user) {
    var _this = this;

    return this.storage.onConnect().then(function () {
      _this.authenticated = true;
      _this.token = user.token;
      return _this.storage.set('auth', JSON.stringify(user));
    });
  };

  _proto.logout = function logout() {
    var _this2 = this;

    return this.storage.onConnect().then(function () {
      return _this2.storage.del('auth', 'community').then(function () {
        _this2.token = undefined;
        _this2.session = {};
        return Promise.resolve();
      });
    });
  };

  _proto.getAsyncSession = function getAsyncSession() {
    var _this3 = this;

    return this.storage.onConnect().then(function () {
      return _this3.storage.get('auth', 'community');
    }).then(function (args) {
      var authJson = args[0];
      var communityJson = args[1];

      if (authJson) {
        var dataSession = {
          token: JSON.parse(authJson).token,
          community: communityJson ? JSON.parse(communityJson) : {}
        };
        return Promise.resolve(dataSession);
      }
    });
  };

  _proto.setAsyncItem = function setAsyncItem(key, value) {
    var _this4 = this;

    return this.storage.onConnect().then(function () {
      return _this4.storage.set(key, JSON.stringify(value));
    });
  };

  return SessionStorage;
}();

var createGraphQLClient = (function (uri, session, policies) {
  if (session === void 0) {
    session = {};
  }

  if (policies === void 0) {
    policies = {};
  }

  var apolloClientOpts = {
    uri: uri,
    cache: new InMemoryCache(policies),
    headers: {
      'client-name': 'bonde-core-tools [web]',
      'client-version': '1.0.0'
    }
  };

  if (session.token) {
    apolloClientOpts.headers['authorization'] = "Bearer " + session.token;
  }

  return new ApolloClient(apolloClientOpts);
});

var _templateObject;
var FETCH_USER = /*#__PURE__*/gql(_templateObject || (_templateObject = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  query CurrentUser {\n    currentUser {\n      id\n      firstName\n      lastName\n      email\n      createdAt\n      avatar\n      isAdmin\n    }\n  }\n"])));
var FetchUser = (function (_ref) {
  var children = _ref.children,
      Loading = _ref.loading,
      logout = _ref.logout;

  var _useQuery = useQuery(FETCH_USER),
      loading = _useQuery.loading,
      error = _useQuery.error,
      data = _useQuery.data;

  if (loading) return React.createElement(Loading, {
    fetching: "user"
  });

  if (error || !data.currentUser) {
    console.log('error', {
      error: error,
      data: data
    });
    logout();
  }

  return children({
    user: data.currentUser
  });
});

var _templateObject$1;
var FETCH_RELATED_COMMUNITIES = /*#__PURE__*/gql(_templateObject$1 || (_templateObject$1 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  query RelatedCommunities {\n    communities {\n      id\n      name\n      city\n      description\n      image\n      created_at\n      updated_at\n      mailchimp_api_key\n      mailchimp_list_id\n      mailchimp_group_id\n      fb_link\n      twitter_link\n      facebook_app_id\n      email_template_from\n      modules\n      signature\n\n      recipient {\n        id\n        pagarme_recipient_id\n        transfer_day: recipient(path: \"transfer_day\")\n        transfer_interval: recipient(path: \"transfer_interval\")\n        transfer_enabled: recipient(path: \"transfer_enabled\")\n        bank_account: recipient(path: \"bank_account\")\n      }\n    }\n  }\n"])));
var FetchCommunities = (function (_ref) {
  var children = _ref.children,
      Loading = _ref.loading;

  var _useQuery = useQuery(FETCH_RELATED_COMMUNITIES, {
    fetchPolicy: "network-only"
  }),
      loading = _useQuery.loading,
      error = _useQuery.error,
      data = _useQuery.data;

  if (loading) return React.createElement(Loading, {
    fetching: "communities"
  });

  if (error || !data.communities) {
    console.log('error', {
      error: error,
      data: data
    });
    return children({
      communities: []
    });
  }

  return children({
    communities: data.communities
  });
});

var nextURI = (function (uri) {
  return uri + "?next=" + window.location.href;
});

var bondeConfig = {
  development: {
    // Modules URLs
    accounts: 'http://bonde.devel:5000/login',
    settings: 'http://bonde.devel:5002/community/settings',
    mobilization: 'http://bonde.devel:5001/mobilizations',
    chatbot: 'http://bonde.devel:5005',
    redes: 'http://bonde.devel:5004',
    // Essentials URLs
    crossStorage: 'http://bonde.devel:5003',
    apiGraphql: 'http://api-graphql.bonde.devel/v1/graphql'
  },
  staging: {
    // Modules URLs
    accounts: 'https://accounts.staging.bonde.org/login',
    mobilization: 'https://app.staging.bonde.org/mobilizations',
    settings: 'https://admin-canary.staging.bonde.org/community/settings',
    chatbot: 'https://chatbot.staging.bonde.org',
    redes: 'https://redes.staging.bonde.org',
    // Essentials URLs
    crossStorage: 'https://cross-storage.staging.bonde.org',
    apiGraphql: 'https://api-graphql.staging.bonde.org/v1/graphql'
  },
  production: {
    // Modules URLs
    accounts: 'https://accounts.bonde.org/login',
    mobilization: 'https://app.bonde.org/mobilizations',
    settings: 'https://admin-canary.bonde.org/community/settings',
    chatbot: 'https://chatbot.bonde.org',
    redes: 'https://redes.bonde.org',
    // Essentials URLs
    crossStorage: 'https://cross-storage.bonde.org',
    apiGraphql: 'https://api-graphql.bonde.org/v1/graphql'
  }
};

var settings = (function (environment) {
  var defaultConfig = bondeConfig.development;
  var environmentConfig = bondeConfig[environment];
  return Object.assign({}, defaultConfig, environmentConfig);
});

/**
 * Responsible to control session used on cross-storage
 **/

var Context = /*#__PURE__*/createContext({
  signing: true,
  isLogged: false
});

var SessionProvider = function SessionProvider(_ref) {
  var children = _ref.children,
      environment = _ref.environment,
      extraConfig = _ref.extraConfig,
      fetchData = _ref.fetchData,
      Loading = _ref.loading,
      policies = _ref.policies;

  // 0. Start controller states
  var _useState = useState(false),
      redirecting = _useState[0],
      setRedirecting = _useState[1];

  var _useState2 = useState(undefined),
      token = _useState2[0],
      setToken = _useState2[1];

  var _useState3 = useState(true),
      signing = _useState3[0],
      setSigning = _useState3[1];

  var _useState4 = useState(0),
      refetch = _useState4[0],
      setRefetch = _useState4[1];

  var _useState5 = useState(undefined),
      community = _useState5[0],
      setCommunity = _useState5[1]; // 1. Merge settings to start BondeSessionProvider requests


  var config = Object.assign({}, settings(environment), extraConfig); // 2. Create a SessionStorage client connect on cross-storage

  var storage = new SessionStorage(config.crossStorage);

  var fetchSession = function fetchSession() {
    // Function to fetch a shared session
    storage.getAsyncSession().then(function (_temp) {
      var _ref2 = _temp === void 0 ? {} : _temp,
          stoken = _ref2.token,
          scommunity = _ref2.community;

      if (!stoken) throw Error('unauthorized');
      setToken(stoken);
      setSigning(false);
      setCommunity(!!Object.keys(scommunity || {}).length ? scommunity : undefined);
      return Promise.resolve();
    })["catch"](function (err) {
      // TODO: change url admin-canary
      if (err && err.message === 'unauthorized') {
        if (config && config.accounts) {
          window.location.href = nextURI(config.accounts);
        }

        setToken(undefined);
        setSigning(false);
      } else {
        // reload fetchSession when error not authorized
        console.log('err', err.message);
        setRefetch(refetch + 1);
        if (refetch < 3) fetchSession();
      }
    });
  };

  useEffect(function () {
    if (!token) return fetchSession(); // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [token]);

  var login = function login(user) {
    return storage.login(user);
  };

  var logout = function logout() {
    return storage.logout().then(function () {
      if (config && config.accounts) {
        window.location.href = config.accounts;
      }

      return Promise.resolve();
    })["catch"](function (err) {
      return console.log('err', err);
    });
  }; // TODO: Tratar erros */


  var onChange = function onChange(props) {
    if (!!props.community) {
      storage.setAsyncItem('community', props.community);
      setCommunity(props.community);
    }

    if (!!props.url) {
      window.location.href = props.url;
      setRedirecting(true);
    }
  };

  var onChangeAsync = function onChangeAsync(props) {
    try {
      return Promise.resolve(new Promise(function (resolve) {
        console.log("onChange promise", props);
        onChange(props);
        return resolve();
      }));
    } catch (e) {
      return Promise.reject(e);
    }
  };

  var session = {
    storage: storage,
    signing: signing,
    token: token,
    community: community,
    onChange: onChange,
    onChangeAsync: onChangeAsync,
    login: login,
    logout: logout,
    config: config,
    isLogged: !!token,
    loading: Loading
  };
  return signing ? React.createElement(Loading, {
    fetching: "session"
  }) : redirecting ? React.createElement(Loading, {
    fetching: "module"
  }) : React.createElement(ApolloProvider, {
    client: createGraphQLClient(config.apiGraphql, session, policies)
  }, fetchData && session.isLogged ? React.createElement(FetchUser, {
    loading: Loading,
    logout: logout
  }, function (user) {
    return React.createElement(FetchCommunities, {
      loading: Loading
    }, function (communities) {
      console.log("communities", {
        communities: communities,
        community: community
      });
      return React.createElement(Context.Provider, {
        value: _extends({}, session, user, communities)
      }, children);
    });
  }) : fetchData && !session.isLogged ? React.createElement(Loading, {
    fetching: "redirect"
  }) : React.createElement(Context.Provider, {
    value: session
  }, children));
};

SessionProvider.defaultProps = {
  environment: 'development',
  fetchData: false
};
var useSession = function useSession() {
  return useContext(Context);
};

var items = {
  settings: [SettingsIcon, 'Configurações'],
  mobilization: [PagesIcon, 'Mobilizações'],
  redes: [NetIcon, 'Redes'],
  chatbot: [BotIcon, 'Chatbot']
};

var CommunityNavigation = function CommunityNavigation(_ref) {
  var community = _ref.community,
      inverted = _ref.inverted;

  var _useSession = useSession(),
      onChange = _useSession.onChange,
      config = _useSession.config;

  var modules = community.modules;

  var handleClick = function handleClick(url) {
    return function () {
      try {
        return Promise.resolve(onChange({
          community: community,
          url: url
        })).then(function () {});
      } catch (e) {
        return Promise.reject(e);
      }
    };
  };

  return React.createElement(Stack, {
    direction: "row",
    spacing: 2
  }, Object.keys(modules).filter(function (key) {
    return !!modules[key];
  }).map(function (key, index) {
    var moduleHost = new URL('', config[key]).host;
    var baseHost = new URL('', window.location.href).host;

    var hoverColor = function hoverColor(color) {
      return {
        color: color + ".200"
      };
    };

    var isActive = moduleHost === baseHost;
    var IconComponent = items[key][0];
    var colorSystem = inverted ? {
      color: isActive ? "pink.200" : "white",
      _hover: isActive ? hoverColor("pink") : hoverColor("gray")
    } : {
      color: "gray.400",
      _hover: hoverColor("gray")
    };
    return React.createElement(IconButton, {
      key: "community-navigation-" + index,
      variant: "link",
      colorScheme: "gray",
      title: items[key][1],
      icon: React.createElement(IconComponent, Object.assign({}, colorSystem, {
        boxSize: 4
      })),
      onClick: handleClick(config[key])
    });
  }));
};

var CommunitiesDropdown = function CommunitiesDropdown() {
  var _useSession = useSession(),
      community = _useSession.community,
      communities = _useSession.communities,
      onChange = _useSession.onChange;

  return React.createElement(Stack, {
    direction: "row",
    spacing: 2
  }, React.createElement(PerformDropdown, null, React.createElement(PerformDropdownButton, {
    variant: "link",
    color: "white"
  }, community ? React.createElement(Stack, {
    direction: "row",
    spacing: 4,
    alignItems: "center"
  }, React.createElement(Image, {
    boxSize: 6,
    rounded: "50%",
    src: (community === null || community === void 0 ? void 0 : community.image) || "https://via.placeholder.com/100?text=" + community.name.substring(0, 1)
  }), React.createElement(Text, {
    color: "white",
    fontSize: "sm",
    fontWeight: "extrabold",
    textTransform: "uppercase"
  }, community === null || community === void 0 ? void 0 : community.name)) : "Selecione uma comunidade"), React.createElement(PerformDropdownList, {
    scroll: communities.length > 10
  }, communities.map(function (c) {
    return React.createElement(PerformDropdownItem, {
      key: c.id,
      onClick: function onClick() {
        onChange({
          community: c
        });
      }
    }, React.createElement(Stack, {
      direction: "row",
      spacing: 4,
      p: 4
    }, React.createElement(Image, {
      boxSize: 8,
      rounded: "50%",
      src: c.image || "https://via.placeholder.com/100?text=" + c.name.substring(0, 1)
    }), React.createElement(Text, null, c.name)));
  }))), community && React.createElement(CommunityNavigation, {
    community: community,
    inverted: true
  }));
};

var UserDropdown = function UserDropdown() {
  var _useSession = useSession(),
      user = _useSession.user,
      logout = _useSession.logout;

  var name = user.firstName + " " + user.lastName;
  var title = React.createElement(Stack, {
    spacing: 1
  }, React.createElement(Heading, {
    as: "h3",
    size: "md",
    fontWeight: "extrabold",
    textTransform: "capitalize"
  }, name), React.createElement(Text, {
    fontSize: "md",
    color: "gray.200"
  }, user.email));
  return React.createElement(Menu, {
    variant: "link",
    colorScheme: "pink"
  }, function (_ref) {
    var isOpen = _ref.isOpen;
    return React.createElement(React.Fragment, null, React.createElement(MenuButton, {
      "aria-label": "User Menu",
      as: Button,
      variant: "dropdown",
      color: "white",
      rightIcon: isOpen ? React.createElement(ArrowUpIcon, {
        boxSize: 3
      }) : React.createElement(ArrowDownIcon, {
        boxSize: 3
      })
    }, name), React.createElement(MenuList, {
      zIndex: "3"
    }, React.createElement(MenuGroup, {
      title: title
    }, React.createElement(MenuItem, {
      onClick: logout,
      icon: React.createElement(CloseIcon, {
        boxSize: 3
      })
    }, "Logout"))));
  });
};

var _templateObject$2;
var Content = /*#__PURE__*/styled.div(_templateObject$2 || (_templateObject$2 = /*#__PURE__*/_taggedTemplateLiteralLoose(["\n  display: flex;\n  flex-grow: 1;\n  background-color: ", ";\n"])), function (props) {
  return props.bgColor;
});

var BondeSessionUI = function BondeSessionUI(_ref) {
  var children = _ref.children,
      bgColor = _ref.bgColor,
      disableNavigation = _ref.disableNavigation,
      indexRoute = _ref.indexRoute,
      LanguageTool = _ref.languageTool;
  return React.createElement(Main, null, React.createElement(Navbar, {
    indexRoute: indexRoute,
    brand: disableNavigation ? 'default' : 'small'
  }, React.createElement(Flex, {
    direction: "row",
    grow: 1,
    justify: "space-between"
  }, disableNavigation ? React.createElement("div", null) : React.createElement(CommunitiesDropdown, null), React.createElement(UserDropdown, null))), React.createElement(Content, {
    bgColor: bgColor || 'rgb(247,247,247)'
  }, children), LanguageTool ? React.createElement(Footer, null, React.createElement(LanguageTool, null)) : React.createElement(Footer, null));
};

BondeSessionUI.defaultProps = {
  disableNavigation: false
};

// A type of promise-like that resolves synchronously and supports only one observer

const _iteratorSymbol = /*#__PURE__*/ typeof Symbol !== "undefined" ? (Symbol.iterator || (Symbol.iterator = Symbol("Symbol.iterator"))) : "@@iterator";

const _asyncIteratorSymbol = /*#__PURE__*/ typeof Symbol !== "undefined" ? (Symbol.asyncIterator || (Symbol.asyncIterator = Symbol("Symbol.asyncIterator"))) : "@@asyncIterator";

// Asynchronously call a function and send errors to recovery continuation
function _catch(body, recover) {
	try {
		var result = body();
	} catch(e) {
		return recover(e);
	}
	if (result && result.then) {
		return result.then(void 0, recover);
	}
	return result;
}

var logger = /*#__PURE__*/logger$1();

var log = /*#__PURE__*/logger.child({
  module: 'geolocation'
});

var getCityStateAndZipcode = function getCityStateAndZipcode(addressComponents) {
  var state = '';
  var city = '';
  var zipcode = '';
  var country = '';
  addressComponents.forEach(function (_ref) {
    var types = _ref.types,
        shortName = _ref.short_name;

    if (types.includes('postal_code')) {
      zipcode = shortName;
    }

    if (types.includes('administrative_area_level_1')) {
      state = shortName;
    }

    if (types.includes('administrative_area_level_2')) {
      city = shortName;
    } else if (types.includes('locality')) {
      city = shortName;
    }

    if (types.includes('country')) {
      country = shortName;
    }
  });

  if (country !== 'BR') {
    city = 'Internacional';
    zipcode = 'Internacional';
    state = 'INT';
  }

  return [state, city, zipcode];
};

var geolocationUnkown = function geolocationUnkown(_ref2) {
  var address = _ref2.address,
      zipcode = _ref2.zipcode;
  return {
    latitude: null,
    longitude: null,
    address: "Endere\xE7o n\xE3o encontrado - " + (address || zipcode),
    state: null,
    city: 'ZERO_RESULTS',
    cep: zipcode || null
  };
};

var parseZipcode = function parseZipcode(zipcode) {
  var specialCharactersRegex = /[^\w\s+]/gi;
  var whiteSpaceRegex = /\s+/g;
  return zipcode.replace(specialCharactersRegex, '').replace(whiteSpaceRegex, '');
};

var processGoogleResponse = function processGoogleResponse(userEmail, searchAddress, data) {
  if (data && data.status === 'OK') {
    var _data$results = data.results,
        _data$results$ = _data$results[0],
        _data$results$$geomet = _data$results$.geometry.location,
        _data$results$$geomet2 = _data$results$$geomet.lat,
        lat = _data$results$$geomet2 === void 0 ? '' : _data$results$$geomet2,
        _data$results$$geomet3 = _data$results$$geomet.lng,
        lng = _data$results$$geomet3 === void 0 ? '' : _data$results$$geomet3,
        addressComponents = _data$results$.address_components,
        _data$results$$format = _data$results$.formatted_address,
        address = _data$results$$format === void 0 ? '' : _data$results$$format;

    var _getCityStateAndZipco = getCityStateAndZipcode(addressComponents),
        state = _getCityStateAndZipco[0],
        city = _getCityStateAndZipco[1],
        zipcode = _getCityStateAndZipco[2];

    var latitude = typeof lat === 'string' ? lat : lat.toFixed(3);
    var longitude = typeof lng === 'string' ? lng : lng.toFixed(3);
    var i = {
      latitude: latitude,
      longitude: longitude,
      address: address,
      state: state,
      city: city,
      cep: zipcode
    };
    log.info('returned valid individual geolocation data');
    return i;
  }

  if (data && data.status === 'ZERO_RESULTS') {
    log.warn("google maps return with zero result (email, address): '" + userEmail + "', " + searchAddress);
  }

  return geolocationUnkown({
    address: searchAddress
  });
};
var getGoogleGeolocation = function getGoogleGeolocation(address, email) {
  try {
    return Promise.resolve(_catch(function () {
      var GOOGLE_MAPS_API_KEY = process.env.GOOGLE_MAPS_API_KEY;

      if (!GOOGLE_MAPS_API_KEY) {
        throw new Error('Please specify the `GOOGLE_MAPS_API_KEY` environment variable.');
      }

      log.info("requesting google with address " + address + "...");
      return Promise.resolve(axios.post('https://maps.googleapis.com/maps/api/geocode/json', undefined, {
        params: {
          address: address,
          key: GOOGLE_MAPS_API_KEY
        }
      })).then(function (response) {
        log.info('google maps responded!');

        if (response.data && response.data.error_message) {
          log.warn("google maps response failed (email, address): '" + email + "', " + address + " %o", response.data.error_message);
          return processGoogleResponse(email, address, undefined);
        }

        return processGoogleResponse(email, address, response.data);
      });
    }, function (e) {
      log.warn("google maps response failed (email, address): '" + email + "', " + address + " %o", e);
      return processGoogleResponse(email, address, undefined);
    }));
  } catch (e) {
    return Promise.reject(e);
  }
};

var getLatLngAddressWithOpenCage = function getLatLngAddressWithOpenCage(_ref3, email) {
  var state = _ref3.state,
      city = _ref3.city,
      neighborhood = _ref3.neighborhood,
      street = _ref3.street;

  try {
    var completeAddress = street + ", " + neighborhood + ", " + city + ", " + state;
    var apikey = process.env.GEOCODING_API_KEY;
    var apiUrl = 'https://api.opencagedata.com/geocode/v1/json';
    var requestUrl = apiUrl + "?key=" + apikey + "&q=" + encodeURIComponent(completeAddress) + "&countrycode=br&pretty=1&no_annotations=1";
    return Promise.resolve(_catch(function () {
      log.info("requesting open cage with complete address " + completeAddress + "...");
      return Promise.resolve(axios.get(requestUrl)).then(function (_ref4) {
        var _ref4$data = _ref4.data,
            status = _ref4$data.status,
            results = _ref4$data.results;
        log.info("Open cage responded!");
        if (status.code !== 200) throw new Error("Open cage responded with an error " + status.message);
        if (results.length < 1) throw new Error("Open cage responded with zero results");
        return {
          latitude: results[0].geometry.lat.toString(),
          longitude: results[0].geometry.lng.toString(),
          address: results[0].formatted
        };
      });
    }, function (e) {
      log.error("Open cage response failed (email, zipcode): '" + email + "', " + completeAddress + " %o", e);
      return {
        latitude: null,
        longitude: null,
        address: null
      };
    }));
  } catch (e) {
    return Promise.reject(e);
  }
};

var getBrasilApiLocation = function getBrasilApiLocation(zipcode, email) {
  try {
    var cleanZipcode = parseZipcode(zipcode);
    return Promise.resolve(_catch(function () {
      if (!process.env.GEOCODING_API_KEY) {
        throw new Error('Please specify the `GEOCODING_API_KEY` environment variable.');
      }

      log.info("requesting BrasilAPI with zipcode " + cleanZipcode + "...");
      return Promise.resolve(axios.get("https://brasilapi.com.br/api/cep/v1/" + cleanZipcode)).then(function (response) {
        log.info('BrasilAPI responded!');
        var _response$data = response.data,
            state = _response$data.state,
            city = _response$data.city,
            cep = _response$data.cep;
        return Promise.resolve(getLatLngAddressWithOpenCage(response.data, email)).then(function (_ref5) {
          var latitude = _ref5.latitude,
              longitude = _ref5.longitude,
              address = _ref5.address;

          if (response.statusText === 'OK' && latitude && longitude && address) {
            return {
              latitude: latitude,
              longitude: longitude,
              address: address,
              state: state,
              city: city,
              cep: cep
            };
          }

          throw new Error('Insufficient response from BrasilAPI and OpenCage');
        });
      });
    }, function (e) {
      log.error("BrasilAPI response failed (email, zipcode): '" + email + "', " + cleanZipcode + " %o", e);
      return null;
    }));
  } catch (e) {
    return Promise.reject(e);
  }
};

var index = (function (_ref6) {
  var state = _ref6.state,
      city = _ref6.city,
      cep = _ref6.cep,
      address = _ref6.address,
      neighborhood = _ref6.neighborhood,
      email = _ref6.email;

  try {
    var _exit2 = false;

    var _temp3 = function _temp3(_result) {
      return _exit2 ? _result : getGoogleGeolocation(composeSearchAddress, email);
    };

    var a = address ? address + "," : '';
    var n = neighborhood ? neighborhood + "," : '';
    var c = city ? city + "," : '';
    var s = state ? state + "," : '';
    var z = cep ? cep + ',BR' : '';
    var composeSearchAddress = a + n + c + s + z;

    var _temp4 = function () {
      if (cep) {
        return Promise.resolve(getBrasilApiLocation(cep, email)).then(function (geolocationFromCep) {
          if (!geolocationFromCep) {
            _exit2 = true;
            return getGoogleGeolocation(composeSearchAddress, email);
          }

          _exit2 = true;
          return geolocationFromCep;
        });
      }
    }();

    return Promise.resolve(_temp4 && _temp4.then ? _temp4.then(_temp3) : _temp3(_temp4));
  } catch (e) {
    return Promise.reject(e);
  }
});

export { SessionProvider as BondeSessionProvider, BondeSessionUI, CommunityNavigation as CommunityMenu, index as getGeolocation, useSession };
//# sourceMappingURL=bonde-core-tools.esm.js.map
